/**
 * Copyright © 2025 IAV GmbH Ingenieurgesellschaft Auto und Verkehr, All Rights Reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 * SPDX-License-Identifier: Apache-2.0
 */

import React, { useContext } from "react";
import "../css/globalColors.css";
import { ColorSettingsContext } from "../../contexts/colorsettings";
import "./contentCell.css";
export let CellPaddings = /*#__PURE__*/function (CellPaddings) {
  CellPaddings[CellPaddings["FULL"] = 0] = "FULL";
  CellPaddings[CellPaddings["VERT_RIGHT"] = 1] = "VERT_RIGHT";
  CellPaddings[CellPaddings["BOT_HOR"] = 2] = "BOT_HOR";
  CellPaddings[CellPaddings["BOT_RIGHT"] = 3] = "BOT_RIGHT";
  CellPaddings[CellPaddings["NONE"] = 4] = "NONE";
  return CellPaddings;
}({});
export function ContentCell(props) {
  const colorSettingsContext = useContext(ColorSettingsContext);
  let paddings = "";
  switch (props.paddings) {
    case CellPaddings.FULL:
      paddings = "p-3";
      break;
    case CellPaddings.VERT_RIGHT:
      paddings = "py-3 pr-3";
      break;
    case CellPaddings.BOT_HOR:
      paddings = "pb-3 px-3";
      break;
    case CellPaddings.BOT_RIGHT:
      paddings = "pb-3 pr-3";
      break;
  }
  let columnClass;
  if (props.colWidth) {
    columnClass = "col-" + props.colWidth;
  } else {
    columnClass = "col";
  }
  const innerDivStyle = {
    width: "100%"
  };
  if (!props.clearStyle) {
    innerDivStyle.backgroundColor = colorSettingsContext.currentColors.contentCell.backgroundColor;
  }
  return /*#__PURE__*/React.createElement("div", {
    className: `content-cell ${columnClass}`
  }, /*#__PURE__*/React.createElement("div", {
    className: "flex " + paddings,
    style: {
      height: "100%"
    }
  }, /*#__PURE__*/React.createElement("div", {
    style: innerDivStyle,
    className: colorSettingsContext?.darkmode ? "color-white" : "color-black"
  }, props.children)));
}